@@ -31,7 +31,7 @@ BELLE_SIP_BEGIN_DECLS
  *
  **************************************************************************************/
 typedef struct _belle_sdp_attribute belle_sdp_attribute_t;
-BELLESIP_EXPORT belle_sdp_attribute_t* belle_sdp_attribute_new();
+BELLESIP_EXPORT belle_sdp_attribute_t* belle_sdp_attribute_new(void);
 BELLESIP_EXPORT belle_sdp_attribute_t* belle_sdp_attribute_parse (const char* attribute);
 BELLESIP_EXPORT belle_sdp_attribute_t* belle_sdp_attribute_create (const char* name,const char* value);
 BELLESIP_EXPORT const char* belle_sdp_attribute_get_name(const belle_sdp_attribute_t* attribute);
@@ -45,7 +45,7 @@ BELLESIP_EXPORT unsigned int belle_sdp_attribute_has_value(belle_sdp_attribute_t
  *
  **************************************************************************************/
 typedef struct _belle_sdp_raw_attribute belle_sdp_raw_attribute_t;
-BELLESIP_EXPORT belle_sdp_raw_attribute_t* belle_sdp_raw_attribute_new();
+BELLESIP_EXPORT belle_sdp_raw_attribute_t* belle_sdp_raw_attribute_new(void);
 BELLESIP_EXPORT belle_sdp_raw_attribute_t* belle_sdp_raw_attribute_parse(const char* attribute);
 BELLESIP_EXPORT belle_sdp_raw_attribute_t* belle_sdp_raw_attribute_create(const char* name, const char* value);
 BELLESIP_EXPORT void belle_sdp_raw_attribute_set_value(belle_sdp_raw_attribute_t* attribute, const char* value);
@@ -70,9 +70,9 @@ typedef enum _belle_sdp_rtcp_fb_val_param {
 	BELLE_SDP_RTCP_FB_TMMBR
 } belle_sdp_rtcp_fb_val_param_t;
 typedef struct _belle_sdp_rtcp_fb_attribute belle_sdp_rtcp_fb_attribute_t;
-BELLESIP_EXPORT belle_sdp_rtcp_fb_attribute_t* belle_sdp_rtcp_fb_attribute_new();
+BELLESIP_EXPORT belle_sdp_rtcp_fb_attribute_t* belle_sdp_rtcp_fb_attribute_new(void);
 BELLESIP_EXPORT belle_sdp_rtcp_fb_attribute_t* belle_sdp_rtcp_fb_attribute_parse(const char* attribute);
-BELLESIP_EXPORT belle_sdp_rtcp_fb_attribute_t* belle_sdp_rtcp_fb_attribute_create();
+BELLESIP_EXPORT belle_sdp_rtcp_fb_attribute_t* belle_sdp_rtcp_fb_attribute_create(void);
 BELLESIP_EXPORT int8_t belle_sdp_rtcp_fb_attribute_get_id(const belle_sdp_rtcp_fb_attribute_t* attribute);
 BELLESIP_EXPORT void belle_sdp_rtcp_fb_attribute_set_id(belle_sdp_rtcp_fb_attribute_t* attribute, int8_t id);
 BELLESIP_EXPORT belle_sdp_rtcp_fb_val_type_t belle_sdp_rtcp_fb_attribute_get_type(const belle_sdp_rtcp_fb_attribute_t* attribute);
@@ -89,9 +89,9 @@ BELLESIP_EXPORT void belle_sdp_rtcp_fb_attribute_set_smaxpr(belle_sdp_rtcp_fb_at
  *
  **************************************************************************************/
 typedef struct _belle_sdp_rtcp_xr_attribute belle_sdp_rtcp_xr_attribute_t;
-BELLESIP_EXPORT belle_sdp_rtcp_xr_attribute_t* belle_sdp_rtcp_xr_attribute_new();
+BELLESIP_EXPORT belle_sdp_rtcp_xr_attribute_t* belle_sdp_rtcp_xr_attribute_new(void);
 BELLESIP_EXPORT belle_sdp_rtcp_xr_attribute_t* belle_sdp_rtcp_xr_attribute_parse(const char* attribute);
-BELLESIP_EXPORT belle_sdp_rtcp_xr_attribute_t* belle_sdp_rtcp_xr_attribute_create();
+BELLESIP_EXPORT belle_sdp_rtcp_xr_attribute_t* belle_sdp_rtcp_xr_attribute_create(void);
 BELLESIP_EXPORT const char* belle_sdp_rtcp_xr_attribute_get_rcvr_rtt_mode(const belle_sdp_rtcp_xr_attribute_t* attribute);
 BELLESIP_EXPORT void belle_sdp_rtcp_xr_attribute_set_rcvr_rtt_mode(belle_sdp_rtcp_xr_attribute_t* attribute, const char *mode);
 BELLESIP_EXPORT int belle_sdp_rtcp_xr_attribute_get_rcvr_rtt_max_size(const belle_sdp_rtcp_xr_attribute_t* attribute);
@@ -108,7 +108,7 @@ BELLESIP_EXPORT void belle_sdp_rtcp_xr_attribute_set_voip_metrics(belle_sdp_rtcp
  *
  **************************************************************************************/
 typedef struct _belle_sdp_bandwidth belle_sdp_bandwidth_t;
-BELLESIP_EXPORT belle_sdp_bandwidth_t* belle_sdp_bandwidth_new();
+BELLESIP_EXPORT belle_sdp_bandwidth_t* belle_sdp_bandwidth_new(void);
 BELLESIP_EXPORT belle_sdp_bandwidth_t* belle_sdp_bandwidth_parse (const char* bandwidth);
 BELLESIP_EXPORT int belle_sdp_bandwidth_get_value(const belle_sdp_bandwidth_t* attribute);
 BELLESIP_EXPORT const char* belle_sdp_bandwidth_get_type(const belle_sdp_bandwidth_t* attribute);
@@ -120,7 +120,7 @@ BELLESIP_EXPORT void belle_sdp_bandwidth_set_type(belle_sdp_bandwidth_t* attribu
  *
  **************************************************************************************/
 typedef struct _belle_sdp_connection belle_sdp_connection_t;
-BELLESIP_EXPORT belle_sdp_connection_t* belle_sdp_connection_new();
+BELLESIP_EXPORT belle_sdp_connection_t* belle_sdp_connection_new(void);
 BELLESIP_EXPORT belle_sdp_connection_t* belle_sdp_connection_create(const char* net_type, const char* addr_type, const char* addr);
 BELLESIP_EXPORT belle_sdp_connection_t* belle_sdp_connection_parse (const char* connection);
 BELLESIP_EXPORT const char* belle_sdp_connection_get_address(const belle_sdp_connection_t* connection);
@@ -139,7 +139,7 @@ BELLESIP_EXPORT void belle_sdp_connection_set_range(belle_sdp_connection_t* conn
  *
  **************************************************************************************/
 typedef struct _belle_sdp_email belle_sdp_email_t;
-BELLESIP_EXPORT belle_sdp_email_t* belle_sdp_email_new();
+BELLESIP_EXPORT belle_sdp_email_t* belle_sdp_email_new(void);
 BELLESIP_EXPORT belle_sdp_email_t* belle_sdp_email_parse (const char* email);
 BELLESIP_EXPORT const char* belle_sdp_email_get_value(const belle_sdp_email_t* email);
 BELLESIP_EXPORT void belle_sdp_email_set_value(belle_sdp_email_t* email, const char* value);
@@ -149,7 +149,7 @@ BELLESIP_EXPORT void belle_sdp_email_set_value(belle_sdp_email_t* email, const c
  *
  **************************************************************************************/
 typedef struct _belle_sdp_info belle_sdp_info_t;
-BELLESIP_EXPORT belle_sdp_info_t* belle_sdp_info_new();
+BELLESIP_EXPORT belle_sdp_info_t* belle_sdp_info_new(void);
 BELLESIP_EXPORT belle_sdp_info_t* belle_sdp_info_parse (const char* info);
 BELLESIP_EXPORT const char* belle_sdp_info_get_value(const belle_sdp_info_t* info);
 BELLESIP_EXPORT void belle_sdp_info_set_value(belle_sdp_info_t* info, const char* value);
@@ -159,7 +159,7 @@ BELLESIP_EXPORT void belle_sdp_info_set_value(belle_sdp_info_t* info, const char
  *
  **************************************************************************************/
 //typedef struct _belle_sdp_key belle_sdp_key_t;
-//belle_sdp_key_t* belle_sdp_key_new();
+//belle_sdp_key_t* belle_sdp_key_new(void);
 //belle_sdp_key_t* belle_sdp_key_parse (const char* key);
 //const char* belle_sdp_key_get_key(const belle_sdp_key_t* key);
 //const char* belle_sdp_key_get_method(const belle_sdp_key_t* key);
@@ -172,7 +172,7 @@ BELLESIP_EXPORT void belle_sdp_info_set_value(belle_sdp_info_t* info, const char
  *
  **************************************************************************************/
 typedef struct _belle_sdp_media belle_sdp_media_t;
-BELLESIP_EXPORT belle_sdp_media_t* belle_sdp_media_new();
+BELLESIP_EXPORT belle_sdp_media_t* belle_sdp_media_new(void);
 BELLESIP_EXPORT belle_sdp_media_t* belle_sdp_media_parse (const char* media);
 BELLESIP_EXPORT belle_sdp_media_t* belle_sdp_media_create(const char* media_type
                          ,int media_port
@@ -198,7 +198,7 @@ BELLESIP_EXPORT void belle_sdp_media_set_protocol(belle_sdp_media_t* media, cons
  *
  **************************************************************************************/
 typedef struct _belle_sdp_mime_parameter belle_sdp_mime_parameter_t;
-BELLESIP_EXPORT belle_sdp_mime_parameter_t* belle_sdp_mime_parameter_new();
+BELLESIP_EXPORT belle_sdp_mime_parameter_t* belle_sdp_mime_parameter_new(void);
 BELLESIP_EXPORT belle_sdp_mime_parameter_t* belle_sdp_mime_parameter_create(const char* type, int media_format, int rate,int channel_count);
 BELLESIP_EXPORT int belle_sdp_mime_parameter_get_rate(const belle_sdp_mime_parameter_t* mime_parameter);
 BELLESIP_EXPORT void belle_sdp_mime_parameter_set_rate(belle_sdp_mime_parameter_t* mime_parameter,int rate);
@@ -221,7 +221,7 @@ BELLESIP_EXPORT void belle_sdp_mime_parameter_set_parameters(belle_sdp_mime_para
  *
  **************************************************************************************/
 typedef struct _belle_sdp_media_description belle_sdp_media_description_t;
-BELLESIP_EXPORT belle_sdp_media_description_t* belle_sdp_media_description_new();
+BELLESIP_EXPORT belle_sdp_media_description_t* belle_sdp_media_description_new(void);
 BELLESIP_EXPORT belle_sdp_media_description_t* belle_sdp_media_description_parse (const char* media_description);
 BELLESIP_EXPORT belle_sdp_media_description_t* belle_sdp_media_description_create(const char* media_type
                          	 	 	 	 	 	 	 	 	 	 ,int media_port
@@ -260,7 +260,7 @@ BELLESIP_EXPORT void belle_sdp_media_description_append_values_from_mime_paramet
  *
  **************************************************************************************/
 typedef struct _belle_sdp_origin belle_sdp_origin_t;
-BELLESIP_EXPORT belle_sdp_origin_t* belle_sdp_origin_new();
+BELLESIP_EXPORT belle_sdp_origin_t* belle_sdp_origin_new(void);
 BELLESIP_EXPORT belle_sdp_origin_t* belle_sdp_origin_parse (const char* origin);
 BELLESIP_EXPORT belle_sdp_origin_t* belle_sdp_origin_create(const char* user_name
 											, unsigned int session_id
@@ -286,7 +286,7 @@ BELLESIP_EXPORT void belle_sdp_origin_set_username(belle_sdp_origin_t* origin, c
  *
  **************************************************************************************/
 typedef struct _belle_sdp_phone belle_sdp_phone_t;
-BELLESIP_EXPORT belle_sdp_phone_t* belle_sdp_phone_new();
+BELLESIP_EXPORT belle_sdp_phone_t* belle_sdp_phone_new(void);
 BELLESIP_EXPORT belle_sdp_phone_t* belle_sdp_phone_parse (const char* phone);
 BELLESIP_EXPORT const char* belle_sdp_phone_get_value(const belle_sdp_phone_t* phone);
 BELLESIP_EXPORT void belle_sdp_phone_set_value(belle_sdp_phone_t* phone, const char* value);
@@ -296,7 +296,7 @@ BELLESIP_EXPORT void belle_sdp_phone_set_value(belle_sdp_phone_t* phone, const c
  *
  **************************************************************************************/
 typedef struct _belle_sdp_repeate_time belle_sdp_repeate_time_t;
-BELLESIP_EXPORT belle_sdp_repeate_time_t* belle_sdp_repeate_time_new();
+BELLESIP_EXPORT belle_sdp_repeate_time_t* belle_sdp_repeate_time_new(void);
 BELLESIP_EXPORT belle_sdp_repeate_time_t* belle_sdp_repeate_time_parse (const char* repeate_time);
 BELLESIP_EXPORT const char* belle_sdp_repeate_time_get_value(const belle_sdp_repeate_time_t* repeate_time);
 BELLESIP_EXPORT void belle_sdp_repeate_time_set_value(belle_sdp_repeate_time_t* repeate_time, const char* value);
@@ -306,7 +306,7 @@ BELLESIP_EXPORT void belle_sdp_repeate_time_set_value(belle_sdp_repeate_time_t*
  *
  **************************************************************************************/
 typedef struct _belle_sdp_session_name belle_sdp_session_name_t;
-BELLESIP_EXPORT belle_sdp_session_name_t* belle_sdp_session_name_new();
+BELLESIP_EXPORT belle_sdp_session_name_t* belle_sdp_session_name_new(void);
 BELLESIP_EXPORT belle_sdp_session_name_t* belle_sdp_session_name_create (const char* name);
 BELLESIP_EXPORT const char* belle_sdp_session_name_get_value(const belle_sdp_session_name_t* session_name);
 BELLESIP_EXPORT void belle_sdp_session_name_set_value(belle_sdp_session_name_t* session_name, const char* value);
@@ -316,7 +316,7 @@ BELLESIP_EXPORT void belle_sdp_session_name_set_value(belle_sdp_session_name_t*
  *
  **************************************************************************************/
 typedef struct _belle_sdp_time belle_sdp_time_t;
-BELLESIP_EXPORT belle_sdp_time_t* belle_sdp_time_new();
+BELLESIP_EXPORT belle_sdp_time_t* belle_sdp_time_new(void);
 BELLESIP_EXPORT belle_sdp_time_t* belle_sdp_time_parse (const char* time);
 
 BELLESIP_EXPORT int belle_sdp_time_get_start(const belle_sdp_time_t* time);
@@ -329,7 +329,7 @@ BELLESIP_EXPORT void belle_sdp_time_set_stop(belle_sdp_time_t* time, int value);
  *
  **************************************************************************************/
 typedef struct _belle_sdp_time_description belle_sdp_time_description_t;
-BELLESIP_EXPORT belle_sdp_time_description_t* belle_sdp_time_description_new();
+BELLESIP_EXPORT belle_sdp_time_description_t* belle_sdp_time_description_new(void);
 BELLESIP_EXPORT belle_sdp_time_description_t* belle_sdp_time_description_parse (const char* time_description);
 BELLESIP_EXPORT belle_sdp_time_description_t* belle_sdp_time_description_create (int start,int stop);
 
@@ -343,7 +343,7 @@ BELLESIP_EXPORT void belle_sdp_time_description_set_time(belle_sdp_time_descript
  *
  **************************************************************************************/
 typedef struct _belle_sdp_uri belle_sdp_uri_t;
-BELLESIP_EXPORT belle_sdp_uri_t* belle_sdp_uri_new();
+BELLESIP_EXPORT belle_sdp_uri_t* belle_sdp_uri_new(void);
 BELLESIP_EXPORT belle_sdp_uri_t* belle_sdp_uri_parse (const char* uri);
 BELLESIP_EXPORT const char* belle_sdp_uri_get_value(const belle_sdp_uri_t* uri);
 BELLESIP_EXPORT void belle_sdp_uri_set_value(belle_sdp_uri_t* uri, const char* value);
@@ -353,7 +353,7 @@ BELLESIP_EXPORT void belle_sdp_uri_set_value(belle_sdp_uri_t* uri, const char* v
  *
  **************************************************************************************/
 typedef struct _belle_sdp_version belle_sdp_version_t;
-belle_sdp_version_t* belle_sdp_version_new();
+belle_sdp_version_t* belle_sdp_version_new(void);
 BELLESIP_EXPORT belle_sdp_version_t* belle_sdp_version_create(int version);
 BELLESIP_EXPORT int belle_sdp_version_get_version(const belle_sdp_version_t* version);
 BELLESIP_EXPORT void belle_sdp_version_set_version(belle_sdp_version_t* version, int value);
@@ -364,7 +364,7 @@ BELLESIP_EXPORT void belle_sdp_version_set_version(belle_sdp_version_t* version,
  *
  **************************************************************************************/
 typedef struct _belle_sdp_session_description belle_sdp_session_description_t;
-BELLESIP_EXPORT belle_sdp_session_description_t* belle_sdp_session_description_new();
+BELLESIP_EXPORT belle_sdp_session_description_t* belle_sdp_session_description_new(void);
 BELLESIP_EXPORT belle_sdp_session_description_t* belle_sdp_session_description_parse (const char* session_description);
 
 BELLESIP_EXPORT belle_sip_list_t * belle_sdp_session_description_get_attributes(const belle_sdp_session_description_t *session_description);
